# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2010 Allen Lowe <lallenlowe@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import gtk
import datetime

from dexter.helpers import get_builder

import gettext
from gettext import gettext as _
gettext.textdomain('dexter')

class MergeDialog(gtk.Dialog):
    __gtype_name__ = "MergeDialog"

    def __new__(cls):
        """Special static method that's automatically called by Python when 
        constructing a new instance of this class.
        
        Returns a fully instantiated MergeDialog object.
        """
        builder = get_builder('MergeDialog')
        new_object = builder.get_object('merge_dialog')
        new_object.finish_initializing(builder)
        return new_object

    def finish_initializing(self, builder):
        """Called when we're finished initializing.

        finish_initalizing should be called after parsing the ui definition
        and creating a MergeDialog object with it in order to
        finish initializing the start of the new MergeDialog
        instance.
        """
        # Get a reference to the builder and set up the signals.
        self.builder = builder
        self.builder.connect_signals(self)
        self._setup_data()

    def _setup_data(self):
        self.vbox1 = self.builder.get_object("vbox1")
        self.ok_button = self.builder.get_object("button1")
        self.data = dict()
        self.first_combo = None
        self.middle_combo = None
        self.last_combo = None
        self.org_combo = None
        self.birthday_combo = None

    def populate(self, data):
        self.data = data
        if len(self.data["first"]) > 1:
            self.first_combo = gtk.combo_box_new_text()
            self.first_combo.append_text(_("First Name... "))
            for name in self.data["first"]:
                self.first_combo.append_text(name)
            self.first_combo.set_active(0)
            self.first_combo.connect("changed", self._on_combo_changed, "first")
            self.vbox1.pack_start(self.first_combo, expand=False, fill=True, padding=5)
        elif not self.data["first"]:
            self.data["first"] = ["None"]
        if len(self.data["middle"]) > 1:
            self.middle_combo = gtk.combo_box_new_text()
            self.middle_combo.append_text(_("Middle Name... "))
            for name in self.data["middle"]:
                self.middle_combo.append_text(name)
            self.middle_combo.set_active(0)
            self.middle_combo.connect("changed", self._on_combo_changed, "middle")
            self.vbox1.pack_start(self.middle_combo, expand=False, fill=True, padding=5)
        elif not self.data["middle"]:
            self.data["middle"] = ["None"]
        if len(self.data["last"]) > 1:
            self.last_combo = gtk.combo_box_new_text()
            self.last_combo.append_text(_("Last Name... "))
            for name in self.data["last"]:
                self.last_combo.append_text(name)
            self.last_combo.set_active(0)
            self.last_combo.connect("changed", self._on_combo_changed, "last")
            self.vbox1.pack_start(self.last_combo, expand=False, fill=True, padding=5)
        elif not self.data["last"]:
            self.data["last"] = ["None"]
        if len(self.data["org"]) > 1:
            self.org_combo = gtk.combo_box_new_text()
            self.org_combo.append_text(_("Organization... "))
            for name in self.data["org"]:
                self.org_combo.append_text(name)
            self.org_combo.set_active(0)
            self.org_combo.connect("changed", self._on_combo_changed, "org")
            self.vbox1.pack_start(self.org_combo, expand=False, fill=True, padding=5)
        elif not self.data["org"]:
            self.data["org"] = ["None"]
        if len(self.data["birthday"]) > 1:
            self.birthday_combo = gtk.combo_box_new_text()
            self.birthday_combo.append_text(_("Birthday... "))
            for name in self.data["birthday"]:
                birthdaylist = name.split("-")
                birthday = datetime.datetime(int(birthdaylist[0]),
                                             int(birthdaylist[1]),
                                             int(birthdaylist[2]))
                self.birthday_combo.append_text(birthday.strftime("%B %d, %Y"))
            self.birthday_combo.set_active(0)
            self.birthday_combo.connect("changed", self._on_combo_changed, "birthday")
            self.vbox1.pack_start(self.birthday_combo, expand=False, fill=True, padding=5)
        elif not self.data["birthday"]:
            self.data["birthday"] = ["None"]
        self.vbox1.show_all()

    def all_combos_chosen(self):
        actives = []
        for combo in self.vbox1.get_children():
            actives.append(combo.get_active())
        if 0 in actives:
            return False
        else:
            return True

    def _on_combo_changed(self, widget, param):
        if widget.get_active() != 0:
            if param == "birthday":
                date = datetime.datetime.strptime(widget.get_active_text(), 
                                                            "%B %d, %Y").date()
                datestring = str(date.year) + "-" + str(date.month) + "-" + str(date.day)
                self.data[param] = [datestring]
            else:
                self.data[param] = [unicode(widget.get_active_text())]
        if self.all_combos_chosen():
            self.ok_button.set_sensitive(True)
        else:
            self.ok_button.set_sensitive(False)

    def ok(self, widget, data=None):
        """The user has elected to save the changes.

        Called before the dialog returns gtk.RESONSE_OK from run().
        """
        pass


if __name__ == "__main__":
    dialog = MergeDialog()
    dialog.show()
    gtk.main()
